@@ -773,9 +773,18 @@ class OsmApi:
         self._conn.putrequest(cmd, path)
         self._conn.putheader('User-Agent', self._created_by)
         if auth:
-            base64_user_pass = base64.encodestring(
-                self._username + ':' + self._password
-            ).strip()
+            user_pass = self._username + ':' + self._password
+
+            try:
+                # Python 2
+                base64_user_pass = base64.encodestring(user_pass).strip()
+            except TypeError:
+                # Python 3
+                base64_user_pass = base64.encodestring(
+                    user_pass.encode('ascii')
+                    ).strip()
+                base64_user_pass = base64_user_pass.decode('utf-8')
+
             self._conn.putheader(
                 'Authorization',
                 'Basic ' + base64_user_pass
